@@ -65,3 +65,42 @@ sub detect_languages {
 }
 
 1;
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Plack::I18N::Lexicon::Gettext - Module
+
+=head1 SYNOPSIS
+
+
+
+=head1 DESCRIPTION
+
+
+
+=head1 METHODS
+
+=head2 C<new>
+
+=head2 C<detect_languages>
+
+=head1 AUTHOR
+
+Viacheslav Tykhanovskyi, E<lt>viacheslav.t@gmail.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2015, Viacheslav Tykhanovskyi
+
+This program is free software, you can redistribute it and/or modify it under
+the terms of the Artistic License version 2.0.
+
+This program is distributed in the hope that it will be useful, but without any
+warranty; without even the implied warranty of merchantability or fitness for
+a particular purpose.
+
+=cut
